============================
A beginner's guide to FESTIM
============================

-----------------------
What do I need to know?
-----------------------

Basic knowledge of `Python <https://www.learnpython.org/>`_ is required to make the most out of FESTIM.

New users should familiarise themselves with `Conda <https://anaconda.org/>`_.

FESTIM is under version control with `git <https://git-scm.com/>`_. Even though users don't need git to install FESTIM, it is convenient to have a basic understanding of how it works. You can find `git tutorials <https://git-scm.com/doc>`_ to help you getting started. The `FESTIM source code <https://github.com/festim-dev/FESTIM>`_ is hosted on GitHub.
Git knowledge and a GitHub account is required to open issues and :ref:`contribute to the code <developers_guide>`.

----------------------
Where can I find help?
----------------------

If you're having an issue, the best way to find help is to join the `FESTIM discourse <https://festim.discourse.group>`_. Engage in discussions, ask questions, and connect with other users. This collaborative space allows you to share your experiences and seek assistance. `Slack <https://join.slack.com/t/festim-dev/shared_invite/zt-246hw8d6o-htWASLsbdosUo_2nRKCf9g>`_ is also a good place to discuss.


--------------
Install FESTIM
--------------

Follow the :ref:`installation instructions<Installation>` to install FESTIM on your computer.
